==> com.liferay.commerce.dashboard.web-3.0.12.jar: META-INF/resources/js/forecast/index.es.js <==
Liferay.Loader.define("commerce-dashboard-web@3.0.12/js/forecast/index.es", ['module', 'exports', 'require', 'frontend-js-react-web', 'frontend-js-react-web$react', './ForecastChart.es'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports["default"] = _default;

    var _frontendJsReactWeb = require("frontend-js-react-web");

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    var _ForecastChart = _interopRequireDefault(require("./ForecastChart.es"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { "default": obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * The contents of this file are subject to the terms of the Liferay Enterprise
     * Subscription License ("License"). You may not use this file except in
     * compliance with the License. You can obtain a copy of the License by
     * contacting Liferay, Inc. See the License for the specific language governing
     * permissions and limitations under the License, including but not limited to
     * distribution rights of the Software.
     */
    var Wrapper = function Wrapper(props) {
      return (/*#__PURE__*/_react["default"].createElement(_ForecastChart["default"], props)
      );
    };

    function _default(id, props) {
      (0, _frontendJsReactWeb.render)(Wrapper, props, document.getElementById(id));
    }
    //# sourceMappingURL=index.es.js.map
  }
});
//# sourceMappingURL=index.es.js.map

==> com.liferay.commerce.dashboard.web-3.0.13.jar: META-INF/resources/js/forecast/index.es.js <==
Liferay.Loader.define("commerce-dashboard-web@3.0.13/js/forecast/index.es", ['module', 'exports', 'require', 'frontend-js-react-web', 'frontend-js-react-web$react', './ForecastChart.es'], function (module, exports, require) {
  var define = undefined;
  var global = window;
  {
    Object.defineProperty(exports, "__esModule", {
      value: true
    });
    exports.default = _default;

    var _frontendJsReactWeb = require("frontend-js-react-web");

    var _react = _interopRequireDefault(require("frontend-js-react-web$react"));

    var _ForecastChart = _interopRequireDefault(require("./ForecastChart.es"));

    function _interopRequireDefault(obj) {
      return obj && obj.__esModule ? obj : { default: obj };
    }

    /**
     * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
     *
     * The contents of this file are subject to the terms of the Liferay Enterprise
     * Subscription License ("License"). You may not use this file except in
     * compliance with the License. You can obtain a copy of the License by
     * contacting Liferay, Inc. See the License for the specific language governing
     * permissions and limitations under the License, including but not limited to
     * distribution rights of the Software.
     */
    var Wrapper = function Wrapper(props) {
      return (/*#__PURE__*/_react.default.createElement(_ForecastChart.default, props)
      );
    };

    function _default(id, props) {
      (0, _frontendJsReactWeb.render)(Wrapper, props, document.getElementById(id));
    }
    //# sourceMappingURL=index.es.js.map
  }
});
//# sourceMappingURL=index.es.js.map
